// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `sou` vocabulary
//!
//! This module requires `ns-sou` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**||
//! |**Prefix**|sou|
//! |**Namespace base IRI**|<http://qudt.org/vocab/sou/>|
//! |**Description**||
//! |**Is defined by**|<http://qudt.org/vocab/sou/>|
//!

use crate::namespace;

namespace!(
    "http://qudt.org/vocab/sou/",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Astronomic System Of Units`: 
    ASU, "ASU",
    /// `CGS System of Units`: 
    CGS, "CGS",
    /// `CGS System of Units - EMU`: 
    CGS_EMU, "CGS-EMU",
    /// `CGS System of Units ESU`: 
    CGS_ESU, "CGS-ESU",
    /// `CGS System of Units - Gaussian`: 
    CGS_GAUSS, "CGS-GAUSS",
    /// `Imperial System of Units`: 
    IMPERIAL, "IMPERIAL",
    /// `Planck System of Units`: 
    PLANCK, "PLANCK",
    /// `International System of Units`: 
    SI, "SI",
    /// `Astronomical System of Units (deprecated URI)`: 
    SOU_ASU, "SOU_ASU",
    /// `CGS System of Units (deprecated URI)`: 
    SOU_CGS, "SOU_CGS",
    /// `CGS-EMU System of Units (deprecated URI)`: 
    SOU_CGS_EMU, "SOU_CGS-EMU",
    /// `CGS-ESU System of Units (deprecated URI)`: 
    SOU_CGS_ESU, "SOU_CGS-ESU",
    /// `CGS-Gauss System of Units (deprecated URI)`: 
    SOU_CGS_GAUSS, "SOU_CGS-GAUSS",
    /// `Imperial System of Units (deprecated URI)`: 
    SOU_IMPERIAL, "SOU_IMPERIAL",
    /// `Planck System of Units (deprecated URI)`: 
    SOU_PLANCK, "SOU_PLANCK",
    /// `SI System of Units (deprecated URI)`: 
    SOU_SI, "SOU_SI",
    /// `US Customary System of Units (deprecated URI)`: 
    SOU_USCS, "SOU_USCS",
    /// `US Customary Unit System`: 
    USCS, "USCS"
);
